@@ -13,7 +13,7 @@ var webui_i18n = {
     "GATEWAY TIMEOUT": "نفذ وقت الطلب",
 
     "request cancelled": "تم إلغاء الطلب",
-    "service unavailable": "الخدمة غير متوفرة",
+    "no connection": "لا يوجد اتصال",
     "request failed": "لقد فشل الطلب",
     "Failed to load all page contents !!": "فشل تحميل كافة محتويات الصفحة !!",
     "Please reload page and try again.": "يرجى إعادة تحميل الصفحة والمحاولة مرة أخرى.",
